A function serving as the core of the make_circos_links function. Takes a data frame containing a single lineage, and generates a links data frame containing all possible combinations of that lineage.
generate_searchable_links(df, chromosome_grouping, band_grouping, link_grouping,
start_position, end_position)A data frame containing all sub-lineages from the same lineageID
A column defining the circos chromosomes. Passed as column index or "column name".
A column defining the circos chromosome bands. Passed as column index or "column name".
A column defining the circos linkage IDs. Passed as column index or "column name".
A column defining the start positions of the linkage ID.
A column defining the end positions of the linkage ID.
Returns a data frame in a pre-"circos links" format for later use within the `make_circos_links` function.